Module explain

Module explain 

Model explainability: permutation importance and TreeSHAP.

Structs

PermutationImportance
Result of permutation importance analysis.

Functions

ensemble_tree_shap
Compute SHAP values for a single sample across an ensemble of trees.
permutation_importance
Compute permutation importance for any model.
tree_shap
Compute SHAP values for a single sample on a single FlatTree.