#[non_exhaustive]pub struct Pca { /* private fields */ }Expand description
Principal Component Analysis.
Projects data onto the top-k eigenvectors of the covariance matrix. Optionally whitens the output so each component has unit variance.
Implementations
Sourceimpl Pca
impl Pca
Sourcepub fn with_n_components(k: usize) -> Self
pub fn with_n_components(k: usize) -> Self
Create a PCA that retains the top k components.
Sourcepub fn explained_variance_ratio(&self) -> &[f64]
pub fn explained_variance_ratio(&self) -> &[f64]
Fraction of total variance explained by each retained component.
Sourcepub fn explained_variance(&self) -> &[f64]
pub fn explained_variance(&self) -> &[f64]
Absolute variance (eigenvalue) of each retained component.
Sourcepub fn components(&self) -> &[Vec<f64>]
pub fn components(&self) -> &[Vec<f64>]
Principal axes in feature space — [n_components][n_features].
Sourcepub fn n_components_fitted(&self) -> usize
pub fn n_components_fitted(&self) -> usize
Number of components actually retained after fitting.