#[non_exhaustive]pub enum ParamDistribution {
Categorical(Vec<ParamValue>),
Uniform {
low: f64,
high: f64,
},
LogUniform {
low: f64,
high: f64,
},
IntUniform {
low: usize,
high: usize,
},
}Expand description
A distribution from which hyperparameter values can be sampled.
Used with BayesSearchCV to define a continuous or discrete search space
for each hyperparameter.
Examples
use scry_learn::search::ParamDistribution;
let lr = ParamDistribution::LogUniform { low: 0.001, high: 1.0 };
let depth = ParamDistribution::IntUniform { low: 2, high: 10 };Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Categorical(Vec<ParamValue>)
A set of discrete candidate values (any ParamValue variant).
Uniform
Continuous uniform distribution over [low, high].
LogUniform
Log-uniform distribution over [low, high] (sampled in log space).
Both low and high must be positive.
IntUniform
Discrete uniform distribution over integers [low, high].