#[non_exhaustive]pub struct MiniBatchKMeans { /* private fields */ }Expand description
Mini-Batch K-Means clustering.
Approximates standard K-Means by updating centroids using random mini-batches of the data at each iteration, rather than the full dataset. This is significantly faster for large datasets while producing similar results.
Implementations
Sourceimpl MiniBatchKMeans
impl MiniBatchKMeans
Sourcepub fn batch_size(self, n: usize) -> Self
pub fn batch_size(self, n: usize) -> Self
Set the mini-batch size (default 1024).
Sourcepub fn fit(&mut self, data: &Dataset) -> Result<()>
pub fn fit(&mut self, data: &Dataset) -> Result<()>
Fit the model on a dataset (uses features only, ignores target).