#[non_exhaustive]pub struct VotingClassifier { /* private fields */ }Expand description
Combines multiple classifiers via voting.
In Voting::Hard mode, each estimator votes for a class and the majority
wins. In Voting::Soft mode, predicted probabilities are averaged and
the class with the highest average probability is selected.
Examples
ⓘ
use scry_learn::ensemble::{VotingClassifier, Voting};
use scry_learn::tree::DecisionTreeClassifier;
let vc = VotingClassifier::new(vec![
Box::new(DecisionTreeClassifier::new().max_depth(3)),
Box::new(DecisionTreeClassifier::new().max_depth(5)),
Box::new(DecisionTreeClassifier::new().max_depth(7)),
]).voting(Voting::Hard);Implementations
Sourceimpl VotingClassifier
impl VotingClassifier
Sourcepub fn new(estimators: Vec<Box<dyn EnsembleClassifier>>) -> Self
pub fn new(estimators: Vec<Box<dyn EnsembleClassifier>>) -> Self
Create a new voting classifier with the given base estimators.
Sourcepub fn voting(self, v: Voting) -> Self
pub fn voting(self, v: Voting) -> Self
Set the voting strategy (default: Voting::Hard).
Sourcepub fn weights(self, w: Vec<f64>) -> Self
pub fn weights(self, w: Vec<f64>) -> Self
Set weights for each estimator (default: equal weights).